@@ -86,7 +86,7 @@
 #define KCOMPLETION_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KCOMPLETION_NO_DEPRECATED
-#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54500
+#  define KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
 #endif
 #ifdef KCOMPLETION_NO_DEPRECATED_WARNINGS
 #  define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE KCOMPLETION_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x54500
+#    define KCOMPLETION_DEPRECATED_WARNINGS_SINCE 0x54f00
 #  endif
 #endif
 
@@ -142,5 +142,6 @@
 #define KCOMPLETION_DEPRECATED_VERSION_4(minor, text)      KCOMPLETION_DEPRECATED_VERSION_4_##minor(text)
 #define KCOMPLETION_DEPRECATED_VERSION_5(minor, text)      KCOMPLETION_DEPRECATED_VERSION_5_##minor(text)
 #define KCOMPLETION_DEPRECATED_VERSION(major, minor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KCOMPLETION_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KCOMPLETION_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KCOMPLETION_EXPORT_H */
